@@ -19,7 +19,9 @@
 #include "unicode/dtfmtsym.h"
 #include "unicode/dtptngen.h"
 #include "unicode/ustring.h"
+#include "unicode/datefmt.h"
 #include "cmemory.h"
+#include "cstring.h"
 #include "loctest.h"
 
 
@@ -38,11 +40,15 @@ void IntlTestDateTimePatternGeneratorAPI::runIndexedTest( int32_t index, UBool e
         TESTCASE(4, testC);
         TESTCASE(5, testSkeletonsWithDayPeriods);
         TESTCASE(6, testGetFieldDisplayNames);
+        TESTCASE(7, testJjMapping);
+        TESTCASE(8, test20640_HourCyclArsEnNH);
+        TESTCASE(9, testFallbackWithDefaultRootLocale);
+        TESTCASE(10, testGetDefaultHourCycle_OnEmptyInstance);
         default: name = ""; break;
     }
 }
 
-#define MAX_LOCALE   11
+#define MAX_LOCALE   12
 
 /**
  * Test various generic API methods of DateTimePatternGenerator for API coverage.
@@ -81,11 +87,12 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         {"zh", "Hans", "CN", ""},               // 7
         {"zh", "TW", "", "calendar=roc"},       // 8
         {"ru", "", "", ""},                     // 9
-        {"zh", "", "", "calendar=chinese"},    // 10
+        {"zh", "", "", "calendar=chinese"},     // 10
+        {"ja", "JP", "TRADITIONAL", ""},        // 11
      };
 
     // For Weds, Jan 13, 1999, 23:58:59
-    UnicodeString patternResults[] = {
+    UnicodeString patternResults_en_US[] = {
         // en_US                                              // 0 en_US
         UnicodeString("1/1999"),                              // 00: yM
         UnicodeString("Jan 1999"),                            // 01: yMMM
@@ -104,7 +111,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         UnicodeString("13 Wed"),                              // 14: Ed    -> d EEE
         UnicodeString("11:58:59.123 PM"),                     // 15: jmmssSSS -> "h:mm:ss.SSS a"
         UnicodeString("11:58"),                               // 16: JJmm
+    };
 
+    UnicodeString patternResults_en_US_japanese[] = {
         // en_US@calendar=japanese                            // 1 en_US@calendar=japanese
         UnicodeString("1/11 H"),                              //  0: yM
         UnicodeString("Jan 11 Heisei"),                       //  1: yMMM
@@ -123,7 +132,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         UnicodeString("13 Wed"),                              // 14: Ed    -> d EEE
         UnicodeString("11:58:59.123 PM"),                     // 15: jmmssSSS -> "h:mm:ss.SSS a"
         UnicodeString("11:58"),                               // 16: JJmm
+    };
 
+    UnicodeString patternResults_de_DE[] = {
         // de_DE                                              // 2 de_DE
         UnicodeString("1.1999"),                              // 00: yM
         UnicodeString("Jan. 1999"),                           // 01: yMMM
@@ -142,7 +153,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         UnicodeString("Mi., 13."),                            // 14: Ed   -> EEE d.
         UnicodeString("23:58:59,123"),                        // 15: jmmssSSS -> "HH:mm:ss,SSS"
         UnicodeString("23:58"),                               // 16: JJmm
+    };
 
+    UnicodeString patternResults_fi[] = {
         // fi                                                 // 3 fi
         UnicodeString("1.1999"),                              // 00: yM (fixed expected result per ticket:6626:)
         UnicodeString("tammi 1999"),                          // 01: yMMM
@@ -161,7 +174,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         UnicodeString("ke 13."),                              // 14: Ed    -> ccc d.
         UnicodeString("23.58.59,123"),                        // 15: jmmssSSS -> "H.mm.ss,SSS"
         UnicodeString("23.58"),                               // 16: JJmm
+    };
 
+    UnicodeString patternResults_es[] = {
         // es                                                 // 4 es
         UnicodeString("1/1999"),                              // 00: yM    -> "M/y"
         UnicodeString("ene. 1999"),                           // 01: yMMM  -> "MMM y"
@@ -171,7 +186,7 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         UnicodeString("13 ene."),                             // 05: MMMd  -> "d 'de' MMM"
         UnicodeString("13 de enero"),                         // 06: MMMMd -> "d 'de' MMMM"
         UnicodeString("T1 1999"),                             // 07: yQQQ  -> "QQQ y"
-        UnicodeString("11:58 p. m."),                         // 08: hhmm  -> "hh:mm a"
+        CharsToUnicodeString("11:58 p.\\u00A0m."),            // 08: hhmm  -> "hh:mm a"
         UnicodeString("23:58"),                               // 09: HHmm  -> "HH:mm"
         UnicodeString("23:58"),                               // 10: jjmm  -> "HH:mm"
         UnicodeString("58:59"),                               // 11: mmss  -> "mm:ss"
@@ -180,7 +195,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("mi\\u00E9. 13"),                // 14: Ed    -> "EEE d"
         UnicodeString("23:58:59,123"),                        // 15: jmmssSSS -> "H:mm:ss,SSS"
         UnicodeString("23:58"),                               // 16: JJmm
+    };
 
+    UnicodeString patternResults_ja[] = {
         // ja                                                             // 5 ja
         UnicodeString("1999/1"),                                          // 00: yM    -> y/M
         CharsToUnicodeString("1999\\u5E741\\u6708"),                      // 01: yMMM  -> y\u5E74M\u6708
@@ -199,11 +216,13 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("13\\u65E5(\\u6C34)"),                       // 14: Ed    -> d\u65E5(EEE)
         UnicodeString("23:58:59.123"),                                    // 15: jmmssSSS -> "H:mm:ss.SSS"
         UnicodeString("23:58"),                                           // 16: JJmm
+    };
 
+    UnicodeString patternResults_ja_japanese[] = {
         // ja@calendar=japanese                                           // 6 ja@calendar=japanese
-        CharsToUnicodeString("\\u5E73\\u621011/1"),                       // 00: yM    -> Gy/m
+        UnicodeString("H11/1"),                                           // 00: yM    -> GGGGGy/m
         CharsToUnicodeString("\\u5E73\\u621011\\u5E741\\u6708"),          // 01: yMMM  -> Gy\u5E74M\u6708
-        CharsToUnicodeString("\\u5E73\\u621011/1/13"),                    // 02: yMd   -> Gy/m/d
+        UnicodeString("H11/1/13"),                                        // 02: yMd   -> GGGGGy/m/d
         CharsToUnicodeString("\\u5E73\\u621011\\u5E741\\u670813\\u65E5"), // 03: yMMMd -> Gy\u5E74M\u6708d\u65E5
         UnicodeString("1/13"),                                            // 04: Md    -> M/d
         CharsToUnicodeString("1\\u670813\\u65E5"),                        // 05: MMMd  -> M\u6708d\u65E5
@@ -218,7 +237,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("13\\u65E5(\\u6C34)"),                       // 14: Ed    -> d\u65E5(EEE)
         UnicodeString("23:58:59.123"),                                    // 15: jmmssSSS -> "H:mm:ss.SSS"
         UnicodeString("23:58"),                                           // 16: JJmm
+    };
 
+    UnicodeString patternResults_zh_Hans_CN[] = {
         // zh_Hans_CN                                                     // 7 zh_Hans_CN
         CharsToUnicodeString("1999\\u5E741\\u6708"),                      // 00: yM -> y\u5E74M\u6708
         CharsToUnicodeString("1999\\u5E741\\u6708"),                      // 01: yMMM  -> yyyy\u5E74MMM (fixed expected result per ticket:6626:)
@@ -237,7 +258,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("13\\u65E5\\u5468\\u4E09"),                  // 14: Ed    -> d\u65E5EEE
         CharsToUnicodeString("\\u4E0B\\u534811:58:59.123"),               // 15: jmmssSSS -> "ah:mm:ss.SSS"
         UnicodeString("11:58"),                                           // 16: JJmm
+    };
 
+    UnicodeString patternResults_zh_TW_roc[] = {
         // zh_TW@calendar=roc                                             // 8 zh_TW@calendar=roc
         CharsToUnicodeString("\\u6C11\\u570B88/1"),                       // 00: yM    -> Gy/M
         CharsToUnicodeString("\\u6C11\\u570B88\\u5E741\\u6708"),          // 01: yMMM  -> Gy\u5E74M\u6708
@@ -256,7 +279,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("13 \\u9031\\u4E09"),                        // 14: Ed    -> d E
         CharsToUnicodeString("\\u4E0B\\u534811:58:59.123"),               // 15: jmmssSSS -> "ah:mm:ss.SSS"
         UnicodeString("11:58"),                                           // 16: JJmm
+    };
 
+    UnicodeString patternResults_ru[] = {
         // ru                                                             // 9 ru
         UnicodeString("01.1999"),                                         // 00: yM    -> MM.y
         CharsToUnicodeString("\\u044F\\u043D\\u0432. 1999 \\u0433."),     // 01: yMMM  -> LLL y
@@ -275,7 +300,9 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("\\u0441\\u0440, 13"),                       // 14: Ed    -> EEE, d
         UnicodeString("23:58:59,123"),                                    // 15: jmmssSSS -> "H:mm:ss,SSS"
         UnicodeString("23:58"),                                           // 16: JJmm
+    };
 
+    UnicodeString patternResults_zh_chinese[] = {
         // zh@calendar=chinese                                            // 10 zh@calendar=chinese
         CharsToUnicodeString("1998\\u620A\\u5BC5\\u5E74\\u5341\\u4E00\\u6708"), // 00: yMMM
         CharsToUnicodeString("1998\\u620A\\u5BC5\\u5E74\\u5341\\u4E00\\u6708"), // 01: yMMM
@@ -294,8 +321,42 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
         CharsToUnicodeString("26\\u65E5\\u5468\\u4E09"),                        // 14: Ed    -> d\u65E5EEE
         CharsToUnicodeString("\\u4E0B\\u534811:58:59.123"),                     // 15: jmmssSS
         UnicodeString("11:58"),                                                 // 16: JJmm
+    };
 
-        UnicodeString(),
+    UnicodeString patternResults_ja_jp_traditional[] = {
+        // ja_JP_TRADITIONAL                 // 11 ja_JP_TRADITIONAL
+        u"AD1999/1",                         // 00: yM
+        u"西暦1999年1月",                     // 01: yMMM
+        u"1999年1月13日",                     // 02: yMd
+        u"西暦1999年1月13日",                  // 03: yMMMd
+        u"1/13",                             // 04: Md
+        u"1月13日",                           // 05: MMMd
+        u"1月13日",                           // 06: MMMMd
+        u"西暦1999/Q1",                       // 07: yQQQ
+        u"午後11:58",                         // 08: hhmm
+        u"23:58",                            // 09: HHmm
+        u"23:58",                            // 10: jjmm
+        u"58:59",                            // 11: mmss
+        u"西暦1999年1月",                     // 12: yyyyMMMM
+        u"1月13日(水)",                       // 13: MMMEd
+        u"13日(水)",                          // 14: Ed
+        u"23:58:59.123",                     // 15: jmmssSSS
+        u"23:58",                            // 16: JJmm
+    };
+
+    UnicodeString* patternResults[] = {
+        patternResults_en_US, // 0
+        patternResults_en_US_japanese, // 1
+        patternResults_de_DE, // 2
+        patternResults_fi, // 3
+        patternResults_es, // 4
+        patternResults_ja, // 5
+        patternResults_ja_japanese, // 6
+        patternResults_zh_Hans_CN, // 7
+        patternResults_zh_TW_roc, // 8
+        patternResults_ru, // 9
+        patternResults_zh_chinese, // 10
+        patternResults_ja_jp_traditional, // 11
     };
 
     UnicodeString patternTests2[] = {
@@ -631,6 +692,7 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
     UDate testDate= LocaleTest::date(99, 0, 13, 23, 58, 59) + 123.0;
     while (localeIndex < MAX_LOCALE )
     {
+        resultIndex=0;
         int32_t dataIndex=0;
         UnicodeString bestPattern;
 
@@ -649,9 +711,12 @@ void IntlTestDateTimePatternGeneratorAPI::testAPI(/*char *par*/)
             SimpleDateFormat sdf(bestPattern, loc, status);
             resultDate.remove();
             resultDate = sdf.format(testDate, resultDate);
-            if ( resultDate != patternResults[resultIndex] ) {
+            if ( resultDate != patternResults[localeIndex][resultIndex] ) {
+                auto* calendar = sdf.getCalendar();
                 errln(UnicodeString("\nERROR: Test various skeletons[") + (dataIndex-1) + UnicodeString("], localeIndex ") + localeIndex +
-                      UnicodeString(". Got: \"") + resultDate + UnicodeString("\" Expected: \"") + patternResults[resultIndex] + "\"" );
+                      u". Got: \"" + resultDate +
+                      u"\" with calendar " + calendar->getType() +
+                      u" Expected: \"" + patternResults[localeIndex][resultIndex] + u"\"");
             }
 
             resultIndex++;
@@ -1111,13 +1176,14 @@ void IntlTestDateTimePatternGeneratorAPI::testC() {
             {"en",     "CCCCCCm", "hh:mm aaaaa"},
             {"en-BN",  "Cm",      "h:mm b"},
             {"gu-IN",  "Cm",      "h:mm B"},
-            {"und-IN", "Cm",      "h:mm a"}
+            {"und-IN", "Cm",      "h:mm B"}
     };
 
     UErrorCode status = U_ZERO_ERROR;
     int32_t numTests = UPRV_LENGTHOF(tests);
     for (int32_t i = 0; i < numTests; ++i) {
-        DateTimePatternGenerator *gen = DateTimePatternGenerator::createInstance(Locale(tests[i][0]), status);
+        DateTimePatternGenerator *gen = DateTimePatternGenerator::createInstance(
+                Locale::forLanguageTag(tests[i][0], status), status);
         if (gen == NULL) {
             dataerrln("FAIL: DateTimePatternGenerator::createInstance failed for %s", tests[i][0]);
             return;
@@ -1259,4 +1325,186 @@ void IntlTestDateTimePatternGeneratorAPI::testGetFieldDisplayNames() {
     }
 }
 
+static const UChar timeCycleChars[] = { (UChar)0x0048, (UChar)0x0068, (UChar)0x004B, (UChar)0x006B, (UChar)0 };
+
+void IntlTestDateTimePatternGeneratorAPI::testJjMapping() {
+    UErrorCode status = U_ZERO_ERROR;
+    UnicodeString jSkeleton("j");
+    // First test that j maps correctly by region in a locale for which we do not have data.
+    {
+        const char* testLocaleID = "de_US"; // short patterns from fallback locale "de" have "HH"
+        Locale testLocale(testLocaleID);
+        LocalPointer<DateTimePatternGenerator> dtpg(DateTimePatternGenerator::createInstance(testLocale, status));
+        if (U_FAILURE(status)) {
+            dataerrln("FAIL: DateTimePatternGenerator::createInstance failed for locale %s: %s", testLocaleID, u_errorName(status));
+        } else {
+            UnicodeString jPattern = dtpg->getBestPattern(jSkeleton, UDATPG_MATCH_ALL_FIELDS_LENGTH, status); // get pattern with h e.g. "h 'Uhr' a"
+            if (U_FAILURE(status)) {
+                errln("FAIL: DateTimePatternGenerator::getBestPattern locale %s, pattern j: %s", testLocaleID, u_errorName(status));
+            } else {
+                UnicodeString jPatSkeleton = DateTimePatternGenerator::staticGetSkeleton(jPattern, status); // strip literals, get e.g. "ah"
+                if (U_FAILURE(status)) {
+                    errln("FAIL: DateTimePatternGenerator::staticGetSkeleton locale %s: %s", testLocaleID, u_errorName(status));
+                } else if (jPatSkeleton.indexOf(u'h') < 0) { // expect US preferred cycle 'h', not H or other cycle
+                    errln("ERROR: DateTimePatternGenerator::getBestPattern locale %s, pattern j did not use 'h'", testLocaleID);
+                }
+            }
+        }
+    }
+
+    // Next test that in all available Locales, the actual short time pattern uses the same cycle as produced by 'j'
+    int32_t locCount;
+    const Locale* localePtr = DateFormat::getAvailableLocales(locCount);
+    for (; locCount-- > 0; localePtr++) {
+        const char* localeID = localePtr->getName();
+        status = U_ZERO_ERROR;
+        LocalPointer<DateTimePatternGenerator> dtpg(DateTimePatternGenerator::createInstance(*localePtr, status));
+        if (U_FAILURE(status)) {
+            dataerrln("FAIL: DateTimePatternGenerator::createInstance failed for locale %s: %s", localeID, u_errorName(status));
+            continue;
+        }
+        LocalPointer<DateFormat> dfmt(DateFormat::createTimeInstance(DateFormat::kShort, *localePtr));
+        if (U_FAILURE(status)) {
+            dataerrln("FAIL: DateFormat::createTimeInstance kShort failed for locale %s: %s", localeID, u_errorName(status));
+            continue;
+        }
+        const SimpleDateFormat* sdfmt;
+        if ((sdfmt = dynamic_cast<const SimpleDateFormat*>(reinterpret_cast<const DateFormat*>(dfmt.getAlias()))) == NULL) {
+            continue;
+        }
+        UnicodeString shortPattern;
+        shortPattern = sdfmt->toPattern(shortPattern);
+        UnicodeString jPattern = dtpg->getBestPattern(jSkeleton, status);
+        if (U_FAILURE(status)) {
+            errln("FAIL: DateTimePatternGenerator::getBestPattern locale %s, pattern j: %s", localeID, u_errorName(status));
+            continue;
+        }
+        // Now check that shortPattern and jPattern use the same hour cycle
+        UnicodeString jPatSkeleton = DateTimePatternGenerator::staticGetSkeleton(jPattern, status);
+        UnicodeString shortPatSkeleton = DateTimePatternGenerator::staticGetSkeleton(shortPattern, status);
+        if (U_FAILURE(status)) {
+            errln("FAIL: DateTimePatternGenerator::staticGetSkeleton locale %s: %s", localeID, u_errorName(status));
+            continue;
+        }
+        const UChar* charPtr = timeCycleChars;
+        for (; *charPtr != (UChar)0; charPtr++) {
+             if (jPatSkeleton.indexOf(*charPtr) >= 0) {
+                 if (shortPatSkeleton.indexOf(*charPtr) < 0) {
+                     char jcBuf[2], spBuf[32], jpBuf[32];
+                     u_austrncpy(jcBuf, charPtr, 1);
+                     jcBuf[1] = 0;
+                     shortPattern.extract(0, shortPattern.length(), spBuf, 32);
+                     jPattern.extract(0, jPattern.length(), jpBuf, 32);
+                     const char* dfmtCalType = (dfmt->getCalendar())->getType();
+                     errln("ERROR: locale %s, expected j resolved char %s to occur in short time pattern '%s' for %s (best pattern: '%s')", localeID, jcBuf, spBuf, dfmtCalType, jpBuf);
+                 }
+                 break;
+             }
+        }
+    }
+}
+
+void IntlTestDateTimePatternGeneratorAPI::test20640_HourCyclArsEnNH() {
+    IcuTestErrorCode status(*this, "test20640_HourCyclArsEnNH");
+
+    const struct TestCase {
+        const char* localeName;
+        const char16_t* expectedDtpgPattern;
+        const char16_t* expectedTimePattern;
+        UDateFormatHourCycle expectedDefaultHourCycle;
+    } cases[] = {
+        // ars is interesting because it does not have a region, but it aliases
+        // to ar_SA, which has a region.
+        {"ars", u"h a", u"h:mm a", UDAT_HOUR_CYCLE_12},
+        // en_NH is interesting because NH is a deprecated region code;
+        // formerly New Hebrides, now Vanuatu => VU => h.
+        {"en_NH", u"h a", u"h:mm a", UDAT_HOUR_CYCLE_12},
+        // ch_ZH is a typo (should be zh_CN), but we should fail gracefully.
+        // {"cn_ZH", u"HH", u"H:mm"}, // TODO(ICU-20653): Desired behavior
+        {"cn_ZH", u"HH", u"h:mm a", UDAT_HOUR_CYCLE_23 }, // Actual behavior
+        // a non-BCP47 locale without a country code should not fail
+        {"ja_TRADITIONAL", u"H時", u"H:mm", UDAT_HOUR_CYCLE_23},
+    };
+
+    for (auto& cas : cases) {
+        status.setScope(cas.localeName);
+
+        Locale loc(cas.localeName);
+        LocalPointer<DateFormat> dtf(DateFormat::createTimeInstance(DateFormat::kShort, loc), status);
+        LocalPointer<DateTimePatternGenerator> dtpg(DateTimePatternGenerator::createInstance(loc, status));
+        if (status.errIfFailureAndReset()) {
+            return;
+        }
+
+        UnicodeString timePattern;
+        dynamic_cast<SimpleDateFormat*>(dtf.getAlias())->toPattern(timePattern);
+        UnicodeString dtpgPattern = dtpg->getBestPattern(u"j", status);
+        if (status.errIfFailureAndReset()) {
+            return;
+        }
+        UDateFormatHourCycle defaultHourCycle = dtpg->getDefaultHourCycle(status);
+        if (status.errIfFailureAndReset()) {
+            return;
+        }
+
+        assertEquals(UnicodeString("dtpgPattern ") + cas.localeName,
+            cas.expectedDtpgPattern, dtpgPattern);
+        assertEquals(UnicodeString("timePattern ") + cas.localeName,
+            cas.expectedTimePattern, timePattern);
+        assertEquals(UnicodeString("defaultHour ") + cas.localeName,
+            cas.expectedDefaultHourCycle, defaultHourCycle);
+    }
+
+}
+
+void IntlTestDateTimePatternGeneratorAPI::testFallbackWithDefaultRootLocale() {
+    UErrorCode status = U_ZERO_ERROR;
+    char original[ULOC_FULLNAME_CAPACITY];
+    
+    uprv_strcpy(original, uloc_getDefault());
+    uloc_setDefault("root", &status);
+    if (U_FAILURE(status)) {
+        errln("ERROR: Failed to change the default locale to root! Default is: %s\n", uloc_getDefault());
+    }
+ 
+    DateTimePatternGenerator* dtpg = icu::DateTimePatternGenerator::createInstance("abcdedf", status);
+
+    if (U_FAILURE(status)) {
+        errln("ERROR: expected createInstance with invalid locale to succeed. Status: %s", u_errorName(status));
+    }
+    if (status != U_USING_DEFAULT_WARNING) {
+        errln("ERROR: expected createInstance to return U_USING_DEFAULT_WARNING for invalid locale and default root locale. Status: %s", u_errorName(status));
+    }
+
+    delete dtpg;
+
+    uloc_setDefault(original, &status);
+    if (U_FAILURE(status)) {
+        errln("ERROR: Failed to change the default locale back to %s\n", original);
+    }
+}
+
+// ICU-21000 Ensure that calling getDefaultHourCycle on an empty instance doesn't call UPRV_UNREACHABLE/abort.
+void IntlTestDateTimePatternGeneratorAPI::testGetDefaultHourCycle_OnEmptyInstance() {
+    UErrorCode status = U_ZERO_ERROR;
+
+    LocalPointer<DateTimePatternGenerator> dtpg(DateTimePatternGenerator::createEmptyInstance(status), status);
+    if (U_FAILURE(status)) {
+        errln("ERROR: createEmptyInstance failed, status: %s", u_errorName(status));
+        return;
+    }
+    (void)dtpg->getDefaultHourCycle(status);
+    if (!U_FAILURE(status)) {
+        errln("ERROR: expected getDefaultHourCycle on an empty instance to fail, status: %s", u_errorName(status));
+        return;
+    }
+
+    status = U_USELESS_COLLATOR_ERROR;
+    (void)dtpg->getDefaultHourCycle(status);
+    if (status != U_USELESS_COLLATOR_ERROR) {
+        errln("ERROR: getDefaultHourCycle shouldn't modify status if it is already failed, status: %s", u_errorName(status));
+        return;
+    }
+}
+
 #endif /* #if !UCONFIG_NO_FORMATTING */
